import { FormSchema } from '@/components/Form';
import {BasicColumn} from "@/components/Table";
import {TableColumn} from "ant-design-vue";

export const detailFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '落标检查名称',
    required: true,
    slot: 'name',
  },
  {
    field: 'basicType',
    label: '标准类型',
    slot: 'basicType',
  },
  {
    field: 'describe',
    label: '描述',
    component: 'Input',
  },
  {
    field: 'updateTime',
    label: '更新时间',
    slot: 'updateTime',
  },
  {
    field: 'cycle',
    label: '调度周期',
    slot: 'cycle',
    componentProps: {
      options: [
        {
          label: 'Cron表达式',
          value: 'Cron表达式',
        },
        {
          label: '无周期',
          value: '无周期',
        },
      ],
    },
    colProps: { lg: 6 },
  },
  {
    field: 'formula',
    slot: 'formula',
    colProps: { lg: 18 },
  },
  {
    field: 'type',
    label: '规则选择方式',
    slot: 'type',
    componentProps: {
      options: [
        {
          label: '数据标准',
          value: '数据标准',
        },
        {
          label: '元数据',
          value: '元数据',
        },
      ],
    },
  },
];
export const detailDataColumn: BasicColumn[] = [
  {
    title: '标准',
    dataIndex: 'standard',
    width: 150,
    slots: { customRender: 'standard' },
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 150,
  },
  {
    title: '质量模板',
    dataIndex: 'model',
    width: 150,
  },
  {
    title: '字段名称',
    dataIndex: 'field',
    slots: { customRender: 'field' },
    width: 200,
  },
];
export const detailDataFormSchema: FormSchema[] = [
  {
    field: 'standard',
    component: 'Input',
    componentProps: {
      placeholder: '搜索标准',
    },
    colProps: { lg: 4 },
  },
  {
    field: 'path',
    component: 'Input',
    componentProps: {
      placeholder: '搜索路径',
    },
    colProps: { lg: 4 },
  },
];
export const metadataColumns: BasicColumn[] = [
  {
    title: '字段名称',
    dataIndex: 'name',
    width: 200,
    slots: { customRender: 'name' },
  },
  {
    title: '质量模板',
    dataIndex: 'model',
    width: 100,
  },
  {
    title: '标准',
    dataIndex: 'standard',
    width: 100,
  },
  {
    title: '落标状态',
    dataIndex: 'flag',
    width: 100,
  },
  {
    title: '开启检查',
    dataIndex: 'check',
    width: 100,
    slots: { customRender: 'check' },
  },
];
export const metadataFormSchema: FormSchema[] = [
  {
    field: 'name',
    component: 'Input',
    colProps: { lg: 4 },
  },
];
export const metadataData = [
  {
    businessId: 1,
    name: 'identity',
    nameTxt: '数据中台ArgoDB/dmp/landing_graduates_info/identity',
    model: '非空检查(不为NULL)',
    standard: '身份标识',
    flag: '',
    check: true,
    children: [
      {
        businessId: 1,
        name: '',
        nameTxt: '',
        model: '非空检查(不为NULL)',
        standard: '身份标识',
        flag: '',
        check: true,
      },
      {
        businessId: 1,
        name: '',
        nameTxt: '',
        model: '长度检查[0,50]',
        standard: '身份标识',
        flag: '',
        check: true,
      },
      {
        businessId: 1,
        name: '',
        nameTxt: '',
        model: '公民身份号码',
        standard: '身份标识',
        flag: '',
        check: true,
      },
      {
        businessId: 1,
        name: '',
        nameTxt: '',
        model: '重复',
        standard: '身份标识',
        flag: '',
        check: true,
      },
      {
        businessId: 1,
        name: '',
        nameTxt: '',
        model: '元数据检查',
        standard: '身份标识',
        flag: '',
        check: true,
      },
      {
        businessId: 1,
        name: '',
        nameTxt: '',
        model: '非空检查(不为NULL)',
        standard: '身份标识',
        flag: '',
        check: true,
      },
      {
        businessId: 1,
        name: '',
        nameTxt: '',
        model: '长度检查[0,50]',
        standard: '身份标识',
        flag: '',
        check: true,
      },
      {
        businessId: 1,
        name: '',
        nameTxt: '',
        model: '重复',
        standard: '身份标识',
        flag: '',
        check: true,
      },
      {
        businessId: 1,
        name: '',
        nameTxt: '',
        model: '元数据检查',
        standard: '身份标识',
        flag: '',
        check: true,
      },
    ],
  },
];
export const importFormSchema: FormSchema[] = [
  {
    field: 'methods',
    label: '导入文件选择',
    helpMessage: '导入文件选择',
    labelWidth: 120,
    slot: 'fileMethods',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'type',
    label: '导入策略',
    defaultValue: '增量添加',
    slot: 'type',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '增量添加', value: '增量添加' },
        { label: '全量覆盖', value: '全量覆盖' },
      ],
    },
  },
];
