import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {areaRecord} from "@/api/demo/cascader"; // 引入开关组件
type CheckedType = boolean | string | number;

export const columnsTwo: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '类型',
    dataIndex: 'type',
    width: 120,
  },
]
export const columns: BasicColumn[] = [
  {
    title: '文件中文名',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '文件英文全称',
    dataIndex: 'englishName',
    width: 120,
  },
  {
    title: '名词英文简称',
    dataIndex: 'abbreviation',
    width: 120,
  },
  {
    title: '发布状态',
    dataIndex: 'flag',
    width: 120,
  },
  {
    title: '权属工作组',
    dataIndex: 'group',
    width: 120,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名词中文名',
    component: 'Input',
    colProps: { span: 6 },
    componentProps: {
      placeholder: '输入名词中文名',
    },
  },
  {
    field: 'english',
    label: '名词英文名',
    component: 'Input',
    colProps: { span: 6 },
    componentProps: {
      placeholder: '输入名词英文名',
    },
  },
  {
    field: 'abbreviation',
    label: '名词英文简称',
    component: 'Input',
    colProps: { span: 6 },
    componentProps: {
      placeholder: '输入名词英文简称',
    },
  },
];


export const formSchema: FormSchema[] = [

  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'name',
    label: '名词分类名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名词分类名称',
      },
    ],
  },
  {
    field: 'describe',
    component: 'InputTextArea',
    label: '标准分类描述',
    required: true,
    componentProps: {
      placeholder: '请输入标准分类描述',
      rows: 4,
    },
  },
  {
    field: 'modal',
    component: 'Cascader',
    label: '关联元模型',
    required: true,
    componentProps: {
      // dataField: 'data',
      labelField: 'value',
      valueField: 'label',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
]
export const formSchemaManage: FormSchema[] = [

  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'name',
    label: '名词中文名',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入名词中文名',
      },
    ],
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    defaultValue:'命名字典',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]



/**详情表单1*/
export const detailSchema1: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'valueOne',
    label: '名词中文名称',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'企业号',
    rules: [
      {
        required: true,
        message: '请输入名词中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词中文名称',
    },
  },
  {
    field: 'valueTwo',
    label: '名词英文全称',
    component: 'Input',
    defaultValue: 'REF000023',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入名词英文全称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词英文全称',
    },
  },
  {
    field: 'valueThree',
    label: '名词英文简称',
    component: 'Input',
    defaultValue:'标准文件A',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入名词英文简称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词英文简称',
    },
  },

];
export const detailSchema2: FormSchema[] = [
  {
    field: 'valueOne',
    label: '名词中文名称',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'企业号',
    componentProps: {
      placeholder: '请输入名词中文名称',
    },
  },
  {
    field: 'valueTwo',
    label: '名词英文全称',
    component: 'Input',
    defaultValue: 'company_no',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入名词英文全称',
    },
  },
  {
    field: 'valueThree',
    label: '名词英文简称',
    component: 'Input',
    defaultValue:'company_no',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入名词英文简称',
    },
  },
];
export const detailSchema3: FormSchema[] = [
  {
    field: '',
    label: '域属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'valueOne',
    label: '关联域',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'日期类',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词中文名称',
    },
  },


];
export const detailSchema4: FormSchema[] = [
  {
    field: 'valueOne',
    label: '域名称',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'日期类',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      disabled: true,
      readonly: true,
      placeholder: '请输入名词中文名称',
    },
  },
  {
    field: 'valueTwo',
    label: '父域',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'日期时间型',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueThree',
    label: '字段示例',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'成交日期',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueFour',
    label: '数据类型',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'date',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueFive',
    label: '传统数据库类型',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'date',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueSix',
    label: '长度',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'123',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
  {
    field: 'valueSeven',
    label: '精度',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'-',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
    },
  },
];
export const detailSchema5: FormSchema[] = [
  {
    field: '',
    label: '域属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'valueOne',
    component: 'Cascader',
    label: '关联域',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
];

export const formSchemaPublishTwo: any = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'valueOne',
    label: '数据标准路径',
    component: 'Input',
    defaultValue:'域/共享工作区/短编号',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]
export const formSchemaPublish: any = [
  {
    field: 'title',
    label: '申请标题',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    colProps: { span: 24 },
    componentProps: {
      placeholder: '',
    },
  },
  {
    field: 'reason',
    label: '申请理由',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    colProps: { span: 24 },
    componentProps: {
      placeholder: '',
    },
  },
  {
    field: 'user',
    label: '申请人',
    component: 'Input',
    defaultValue:'admin',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'organization',
    label: '申请人组织',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]
export const formSchemaImport: any = [
  {
    field: 'path',
    label: '选择文件地址',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'name',
    label: '文件名',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件名',
    },
  },
]
