import {getAllRoleList} from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import {h} from "vue";
import {Tag} from "ant-design-vue";
import { Switch } from 'ant-design-vue';
import {useMessage} from "@/hooks/web/useMessage";
import {changeFlagApi} from "@/api/system/user/user";
import {areaRecord} from "@/api/demo/cascader"; // 引入开关组件
type CheckedType = boolean | string | number;

export const columnsTwo: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '类型',
    dataIndex: 'type',
    width: 120,
  },
]
export const batchColumns: BasicColumn[] = [
  {
    title: '日期类',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '共享工作区/日期类',
    dataIndex: 'type',
    width: 120,
  },
]
export const columns: BasicColumn[] = [
  {
    title: '文档名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '文档编号',
    dataIndex: 'num',
    width: 120,
  },
  {
    title: '发布状态',
    dataIndex: 'flag',
    width: 120,
  },
  {
    title: '权属工作组',
    dataIndex: 'group',
    width: 120,
  },

];

export const applySchemas1: FormSchema[] = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    componentProps: {
      placeholder: '搜索资源名称',
    }
  }
]


export const applySchemas3: FormSchema[] = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '资源名称',
    component: 'Input',
    defaultValue:'短编号',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'path',
    label: '标准路径',
    component: 'Input',
    defaultValue:'共享工作区/短编号',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    defaultValue:'域',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]
export const applySchemas2: FormSchema[] = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '资源名称',
    component: 'Input',
    defaultValue:'日期类',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'path',
    label: '标准路径',
    component: 'Input',
    defaultValue:'共享工作区/日期类',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    defaultValue:'域',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]
export const applySchemas: FormSchema[] = [
  {
    field: '',
    label: '申请信息',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '资源名称',
    component: 'Input',
    defaultValue:'申请发布<日期类>等2个域',
    componentProps: {
    }
  },
  {
    field: 'reason',
    label: '申请理由',
    component: 'Input',
    defaultValue:'',
    componentProps: {
    }
  },
  {
    field: 'user',
    label: '申请人',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'org',
    label: '所属机构',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'time',
    label: '申请时间',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '文档名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文档名称',
    },
  },
  {
    field: 'num',
    label: '文档编号',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文档编号',
    },
  },
];


export const formSchema: FormSchema[] = [

  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'name',
    label: '文档分类名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文档分类名称',
      },
    ],
  },
  {
    field: 'describe',
    component: 'InputTextArea',
    label: '标准分类描述',
    required: true,
    componentProps: {
      placeholder: '请输入标准分类描述',
      rows: 4,
    },
  },
  {
    field: 'modal',
    component: 'Cascader',
    label: '关联元模型',
    required: true,
    componentProps: {
      // dataField: 'data',
      labelField: 'value',
      valueField: 'label',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'flag',
    label: '权限模式',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '本级定义', value: '1' },
        { label: '资源自定义', value: '0' },
      ],
    },
  },
  {
    field: 'group',
    label: '权属工作组',
    component: 'Select',
    componentProps: {
      options: [
        { label: '默认工作组', value: '1' },
        { label: '默认工作组2', value: '0' },
      ],
    },
  },
]
export const formSchemaManage: FormSchema[] = [

  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'name',
    label: '文档名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文档分类名称',
      },
    ],
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    defaultValue:'引用文档管理',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'modal',
    label: '目录权属模式',
    component: 'Input',
    defaultValue:'本级定义',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
  {
    field: 'group',
    label: '权属工作组',
    component: 'Input',
    defaultValue:'-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    }
  },
]

/**详情表单1*/
export const detailSchema1: FormSchema[] = [
  {
    field: 'valueOne',
    label: '所属主题',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'标准文件管理',
    rules: [
      {
        required: true,
        message: '请输入所属主题',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入所属主题',
    },
  },
  {
    field: 'valueTwo',
    label: '标准编号',
    component: 'Input',
    defaultValue: 'REF000023',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'valueThree',
    label: '标准中文名称',
    component: 'Input',
    defaultValue:'标准文件A',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'valueFour',
    label: '来源定义',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue: '-',
    rules: [
      {
        required: true,
        message: '请输入来源定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入来源定义',
    },
  },
  {
    field: 'valueFive',
    label: '发文机构',
    component: 'Input',
    defaultValue: '某部队',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入发文机构',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSix',
    label: '发文日期',
    component: 'Input',
    defaultValue: '202304',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入发文日期',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSeven',
    label: '发布文号',
    component: 'Input',
    defaultValue: '2023001',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入发布文号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发布文号',
    },
  },
  {
    field: 'valueEight',
    label: '重点摘录',
    component: 'Input',
    defaultValue: '-',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入重点摘录',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入重点摘录',
    },
  },
];

export const detailSchema2: FormSchema[] = [
  {
    field: 'valueOne',
    label: '所属主题',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue:'标准文件管理',
    componentProps: {
      placeholder: '请输入所属主题',
    },
  },
  {
    field: 'valueTwo',
    label: '标准编号',
    component: 'Input',
    defaultValue: 'REF000023',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'valueThree',
    label: '标准中文名称',
    component: 'Input',
    defaultValue:'标准文件A',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'valueFour',
    label: '来源定义',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue: '-',
    componentProps: {
      placeholder: '请输入来源定义',
    },
  },
  {
    field: 'valueFive',
    label: '发文机构',
    component: 'Input',
    defaultValue: '某部队',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSix',
    label: '发文日期',
    component: 'Input',
    defaultValue: '202304',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSeven',
    label: '发布文号',
    component: 'Input',
    defaultValue: '2023001',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入发布文号',
    },
  },
  {
    field: 'valueEight',
    label: '重点摘录',
    component: 'Input',
    defaultValue: '-',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入重点摘录',
    },
  },
];
export const formSchemaImport: any = [
  {
    field: 'path',
    label: '选择文件地址',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },
  {
    field: 'name',
    label: '文件名',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件名',
    },
  },
]
